@@ -37,8 +37,8 @@ class ClientManager(
         self._config = config
         self._publishers = publishers
 
-        self._async_client = self._config.create_client(Connection.ASYNC)
-        self._sync_client = self._config.create_client(Connection.SYNC)
+        self.async_client = self._config.create_client(Connection.ASYNC)
+        self.sync_client = self._config.create_client(Connection.SYNC)
 
     @overload
     def get(self, connection: Literal[Connection.ASYNC]) -> AsyncClientT: ...
@@ -48,19 +48,19 @@ class ClientManager(
         self, connection: Connection = Connection.ASYNC
     ) -> AsyncClientT | SyncClientT:
         if connection is Connection.ASYNC:
-            return self._async_client
+            return self.async_client
         elif connection is Connection.SYNC:
-            return self._sync_client
+            return self.sync_client
 
     def get_all(self) -> Tuple[AsyncClientT, SyncClientT]:
-        return (self._async_client, self._sync_client)
+        return (self.async_client, self.sync_client)
 
     async def dispose(self):
-        if isinstance(self._async_client, AsyncIOMotorClient):
-            self._async_client.close()
-        elif isinstance(self._async_client, (AsyncElasticsearch, AsyncRedis)):
-            await self._async_client.close()
-        self._sync_client.close()
+        if isinstance(self.async_client, AsyncIOMotorClient):
+            self.async_client.close()
+        elif isinstance(self.async_client, (AsyncElasticsearch, AsyncRedis)):
+            await self.async_client.close()
+        self.sync_client.close()
 
 
 class ElasticsearchClientManager(
@@ -82,8 +82,8 @@ class RedisClientManager(ClientManager[RedisConfig, AsyncRedis, SyncRedis]):
             prefixes = [prefixes]
 
         for prefix in prefixes:
-            async for key in self._async_client.scan_iter(f"{prefix}*"):
-                await self._async_client.delete(key)
+            async for key in self.async_client.scan_iter(f"{prefix}*"):
+                await self.async_client.delete(key)
 
     def sync_clear(self, prefixes: ListOfStrs | str | None = None):
         if prefixes is None:
@@ -93,8 +93,8 @@ class RedisClientManager(ClientManager[RedisConfig, AsyncRedis, SyncRedis]):
             prefixes = [prefixes]
 
         for prefix in prefixes:
-            for key in self._sync_client.scan_iter(f"{prefix}*"):
-                self._sync_client.delete(key)
+            for key in self.sync_client.scan_iter(f"{prefix}*"):
+                self.sync_client.delete(key)
 
 
 ClientManagerT = TypeVar(
