@@ -1,6 +1,6 @@
 from sqlalchemy.engine import Engine
 from sqlalchemy.ext.asyncio import AsyncEngine
-from typing import Generic, Literal, Tuple, TypeVar, Union, overload
+from typing import Generic, Literal, Tuple, TypeVar, overload
 from ..config import (
     MySQLConfig,
     PostgreSQLConfig,
@@ -23,9 +23,7 @@ class EngineManager(Generic[SQLConfigT]):
     def get(self, connection: Literal[Connection.ASYNC]) -> AsyncEngine: ...
     @overload
     def get(self, connection: Literal[Connection.SYNC]) -> Engine: ...
-    def get(
-        self, connection: Connection = Connection.ASYNC
-    ) -> Union[AsyncEngine, Engine]:
+    def get(self, connection: Connection = Connection.ASYNC) -> AsyncEngine | Engine:
         if connection is Connection.ASYNC:
             return self._async_engine
         elif connection is Connection.SYNC:
