@@ -41,14 +41,17 @@ def filter_column(
             )
         return stmt
 
-    value_filters = []
+    filters = []
     if value is not None:
-        value_filters.extend([column_attr == val for val in value])
+        if isinstance(value, list):
+            filters.extend([column_attr == val for val in value])
+        else:
+            filters.append(column_attr == value)
 
-    if value_filters:
+    if filters:
         if include_null:
-            value_filters.append(column_attr.is_(None))
-        stmt = stmt.filter(or_(*value_filters))
+            filters.append(column_attr.is_(None))
+        stmt = stmt.filter(or_(*filters))
 
     return stmt
 
@@ -73,7 +76,10 @@ def filter_columns(
                     f"Invalid column '{column}' for table '{table.__tablename__}'"
                 )
             continue
-        filters.append(column_attr == value)
+        if isinstance(value, list):
+            filters.extend([column_attr == val for val in value])
+        else:
+            filters.append(column_attr == value)
 
     if filters:
         stmt = stmt.filter(or_(*filters) if is_union else and_(*filters))
